.. _James Mills: http://prologic.shortcircuit.net.au
.. _Python: http://www.python.org/
.. _Project Website: https://bitbucket.org/prologic/pymills
.. _PyPi Page: http://pypi.python.org/pypi/pymills
.. _Read the Docs: http://pymills.readthedocs.org/en/latest/
.. _Read the Tutorial: http://pymills.readthedocs.org/en/latest/tutorial.html
.. _Downloads Page: https://bitbucket.org/prologic/pymills/downloads
.. _API: http://pymills.readthedocs.org/en/latest/api.html


pymills is a collection of various useful `Python`_ utility modules
maintained by `James Mills`_. Some are written by James Mills while
others are borrowed from other sources and attributed.

.. note:: You may not find this library/package useful to you
          as I (*James Mills*) don't actively maintain this as
          a real project as such. It was my first ever `Python`_
          Package (*and the name has stuck*) and I generally
          just throw things in it that I can find no better
          place for. See the `API`_ to find anything of interest.

- Visit the `Project Website`_
- `Read the Docs`_
- Download it from the `Downloads Page`_

.. image:: https://pypip.in/v/pymills/badge.png
   :target: https://crate.io/packages/pymills/
   :alt: Latest PyPI version

.. image:: https://pypip.in/d/pymills/badge.png
   :target: https://crate.io/packages/pymills/
   :alt: Number of PyPI downloads

.. image:: https://jenkins.shiningpanda-ci.com/prologic/job/pymills/badge/icon
   :target: https://jenkins.shiningpanda-ci.com/prologic/job/pymills/
   :alt: Build Status


Installation
------------

The simplest and recommended way to install pymills is with pip.
You may install the latest stable release from PyPI with pip::

    > pip install pymills

If you do not have pip, you may use easy_install::

    > easy_install pymills

Alternatively, you may download the source package from the
`PyPI Page`_ or the `Downloads page`_ on the `Project Website`_;
extract it and install using::

    > python setup.py install

You can also install the
`latest-development version <https://bitbucket.org/prologic/pymills/get/tip.tar.gz#egg=pymills-dev>`_ by using ``pip`` or ``easy_install``::
    
    > pip install pymills==dev

or::
    
    > easy_install pymills==dev


For further information see the `pymills documentation <http://pymills-lag.readthedocs.org/>`_.
